==> kubernetes-model-apiextensions-5.7.3-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceColumnDefinitionFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import java.lang.Integer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface CustomResourceColumnDefinitionFluent<A extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinitionFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getJSONPath();
  public A withJSONPath(java.lang.String jSONPath);
  public java.lang.Boolean hasJSONPath();
  
  /**
   * Method is deprecated. use withJSONPath instead.
   */
  @java.lang.Deprecated
  public A withNewJSONPath(java.lang.String arg0);
  public java.lang.String getDescription();
  public A withDescription(java.lang.String description);
  public java.lang.Boolean hasDescription();
  
  /**
   * Method is deprecated. use withDescription instead.
   */
  @java.lang.Deprecated
  public A withNewDescription(java.lang.String arg0);
  public java.lang.String getFormat();
  public A withFormat(java.lang.String format);
  public java.lang.Boolean hasFormat();
  
  /**
   * Method is deprecated. use withFormat instead.
   */
  @java.lang.Deprecated
  public A withNewFormat(java.lang.String arg0);
  public java.lang.String getName();
  public A withName(java.lang.String name);
  public java.lang.Boolean hasName();
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0);
  public java.lang.Integer getPriority();
  public A withPriority(java.lang.Integer priority);
  public java.lang.Boolean hasPriority();
  public java.lang.String getType();
  public A withType(java.lang.String type);
  public java.lang.Boolean hasType();
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0);
  
}

==> kubernetes-model-apiextensions-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceColumnDefinitionFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import java.lang.Integer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface CustomResourceColumnDefinitionFluent<A extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinitionFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getJSONPath();
  public A withJSONPath(java.lang.String jSONPath);
  public java.lang.Boolean hasJSONPath();
  
  /**
   * Method is deprecated. use withJSONPath instead.
   */
  @java.lang.Deprecated
  public A withNewJSONPath(java.lang.String arg0);
  public java.lang.String getDescription();
  public A withDescription(java.lang.String description);
  public java.lang.Boolean hasDescription();
  
  /**
   * Method is deprecated. use withDescription instead.
   */
  @java.lang.Deprecated
  public A withNewDescription(java.lang.String arg0);
  public java.lang.String getFormat();
  public A withFormat(java.lang.String format);
  public java.lang.Boolean hasFormat();
  
  /**
   * Method is deprecated. use withFormat instead.
   */
  @java.lang.Deprecated
  public A withNewFormat(java.lang.String arg0);
  public java.lang.String getName();
  public A withName(java.lang.String name);
  public java.lang.Boolean hasName();
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0);
  public java.lang.Integer getPriority();
  public A withPriority(java.lang.Integer priority);
  public java.lang.Boolean hasPriority();
  public java.lang.String getType();
  public A withType(java.lang.String type);
  public java.lang.Boolean hasType();
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  
}
